import { ValidationPipe as ValidationPipe$1, Catch, BadRequestException } from '@nestjs/common';
import { iterate } from 'iterare';
import { __decorate } from 'tslib';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

class ValidationPipe extends ValidationPipe$1 {
  flattenValidationErrors(validationErrors) {
    return iterate(validationErrors).map(error => this.mapChildrenToValidationErrors(error)).flatten().filter(item => !!item.constraints).map(item => ({
      errors: Object.values(item.constraints || {}),
      field: item.field || item.property
    })).filter(errorObject => errorObject.errors.length > 0).flatten().toArray();
  }

  prependConstraintsWithParentProp(parentPath, error) {
    return _extends({
      field: parentPath + "." + error.property
    }, super.prependConstraintsWithParentProp(parentPath, error));
  }

}

var GraphqlValidationFilter = class GraphqlValidationFilter {
  catch(exception, host) {
    if (host.getType() === 'graphql') {
      // const gqlHost = GqlArgumentsHost.create(host);
      var response = exception.getResponse();

      if (Array.isArray(response.message) && Array.isArray(response.message[0].errors) && typeof response.message[0].field === 'string') {
        return {
          userErrors: response.message.map(error => ({
            field: error.field.split('.'),
            message: error.errors[0]
          }))
        };
      }
    }

    return exception;
  }

};
GraphqlValidationFilter = /*#__PURE__*/__decorate([/*#__PURE__*/Catch(BadRequestException)], GraphqlValidationFilter);

export { GraphqlValidationFilter, ValidationPipe };
//# sourceMappingURL=nestjs-better-validation.esm.js.map
